@@ -176,7 +176,7 @@ a include file I<spec>.h
 (following the language C mapping rules)
 
 =item *
-a C skeleton skel_I<spec>.c0
+a C skeleton skel_I<spec>.c (with automatic merge)
 
 =item *
 Makefile.PL
@@ -205,7 +205,7 @@ The parser is generated by Parse::Yapp.
 
 B<idl2xs_c> needs a B<cpp> executable.
 
-B<idl2xs_c> needs CORBA::IDL and CORBA::C modules.
+B<idl2xs_c> needs CORBA::IDL, CORBA::C and CORBA::Perl modules.
 
 CORBA Specifications, including (IDL : Interface Language Definition and
 CDR : Common Data Representation) and
@@ -226,7 +226,7 @@ First, run :
 
     idl2xs_c Calc.idl
 
-Second, create skel_Calc.c from skel_Calc.c0 by completing each methode between tag
+Second, in skel_Calc.c complete each methode between tag
 START_EDIT and STOP_EDIT :
 
     // IDL : long Add(in long val1, in long val2);
@@ -287,7 +287,7 @@ First, run :
     idl2xs_c Cplx.idl
     idl2xs_c CalcCplx.idl
 
-Second, create skel_CplxCalc.c.
+Second, complete skel_CplxCalc.c.
 
 Third, build :
 
